@@ -1,5 +1,5 @@
 package Google::Client::Files;
-$Google::Client::Files::VERSION = '0.003';
+$Google::Client::Files::VERSION = '0.004';
 use Moo;
 with qw/
 Google::Client::Role::Token
@@ -203,7 +203,7 @@ Ali Zia, C<< <ziali088@gmail.com> >>
 
 =head1 REPOSITORY
 
-https://github.com/ziali088/googleapi-client
+L<https://github.com/ziali088/googleapi-client>
 
 =head1 COPYRIGHT AND LICENSE
 
