@@ -1,5 +1,5 @@
 package Google::Client::Role::FurlAgent;
-$Google::Client::Role::FurlAgent::VERSION = '0.003';
+$Google::Client::Role::FurlAgent::VERSION = '0.004';
 use strict;
 use warnings;
 
@@ -84,7 +84,7 @@ Ali Zia, C<< <ziali088@gmail.com> >>
 
 =head1 REPOSITORY
 
-https://github.com/ziali088/googleapi-client
+L<https://github.com/ziali088/googleapi-client>
 
 =head1 COPYRIGHT AND LICENSE
 
